pub struct TokenBucket { /* private fields */ }Expand description
Token bucket rate limiter.
Implements the token bucket algorithm where tokens are added at a fixed rate up to a maximum capacity. Each request consumes one token.
Implementations
Sourceimpl TokenBucket
impl TokenBucket
Sourcepub fn new(capacity: u64, refill_rate: f64) -> Self
pub fn new(capacity: u64, refill_rate: f64) -> Self
Create a new token bucket.
Arguments
capacity- Maximum tokens (burst size)refill_rate- Tokens added per second
Sourcepub fn try_acquire(&self) -> bool
pub fn try_acquire(&self) -> bool
Try to consume a token.
Returns true if a token was available and consumed, false otherwise.
Sourcepub fn try_acquire_n(&self, n: u64) -> bool
pub fn try_acquire_n(&self, n: u64) -> bool
Try to consume N tokens.
Returns true if N tokens were available and consumed, false otherwise.