pub async fn record_verification_attempt(
pool: &PgPool,
id: Uuid,
) -> ProxyResult<()>Expand description
Increment the verification attempt counter and stamp the attempt time.
pub async fn record_verification_attempt(
pool: &PgPool,
id: Uuid,
) -> ProxyResult<()>Increment the verification attempt counter and stamp the attempt time.